@@ -104,7 +104,7 @@ def plot_emcee_chains(sampler, labels=None, dims = None,thin=1, discard=0, figsi
     assert np.iterable(dims) or dims==None, f"dims must be interable and not {type(dims)}"
     samples = sampler.get_chain(thin = thin, discard=discard)
     nwalkers = samples.shape[2]
-    ndim = samples.shape[1] if dims == None else len(dims)
+    ndim = len(dims) if np.iterable(dims) else samples.shape[2]
     if figsize is None: figsize = (12,7+int(ndim/2))
     fig, axes = plt.subplots(ndim, sharex=True, figsize=figsize)
     
@@ -114,7 +114,7 @@ def plot_emcee_chains(sampler, labels=None, dims = None,thin=1, discard=0, figsi
         axes[0].set_title(f"Thinned by {thin}", fontsize=14)
     else:
         axes[0].set_title(f"Discarded first {discard} steps", fontsize=14)
-    dims = range(ndim) if dims==None else dims
+    dims = dims if np.iterable(dims) else range(ndim)
     for i in dims:
         ax = axes[i]
         ax.plot(samples[:,:,i],"k", alpha=alpha)
